@@ -39,6 +39,9 @@ namespace GLib {
 
 		public static void Free (IntPtr[] ptrs)
 		{
+			if (ptrs == null)
+				return;
+
 			for (int i = 0; i < ptrs.Length; i++)
 				g_free (ptrs [i]);
 		}
@@ -142,7 +145,7 @@ namespace GLib {
 		public static IntPtr[] StringArrayToNullTermPointer (string[] strs)
 		{
 			if (strs == null)
-				return new IntPtr [0];
+				return null;
 			IntPtr[] result = new IntPtr [strs.Length + 1];
 			for (int i = 0; i < strs.Length; i++)
 				result [i] = StringToPtrGStrdup (strs [i]);
@@ -150,6 +153,33 @@ namespace GLib {
 			return result;
 		}
 
+		[DllImport("libglib-2.0-0.dll")]
+		static extern void g_strfreev (IntPtr mem);
+
+		public static void StrFreeV (IntPtr null_term_array)
+		{
+			g_strfreev (null_term_array);
+		}
+
+		public static string[] NullTermPtrToStringArray (IntPtr null_term_array, bool owned)
+		{
+			if (null_term_array == IntPtr.Zero)
+				return new string [0];
+
+			int count = 0;
+			System.Collections.ArrayList result = new System.Collections.ArrayList ();
+			IntPtr s = Marshal.ReadIntPtr (null_term_array, count++ * IntPtr.Size);
+			while (s != IntPtr.Zero) {
+				result.Add (Utf8PtrToString (s));
+				s = Marshal.ReadIntPtr (null_term_array, count++ * IntPtr.Size);
+			}
+
+			if (owned)
+				g_strfreev (null_term_array);
+
+			return (string[]) result.ToArray (typeof(string));
+		}
+
 		public static string[] PtrToStringArrayGFree (IntPtr string_array)
 		{
 			if (string_array == IntPtr.Zero)
@@ -180,6 +210,11 @@ namespace GLib {
 		[DllImport("libglib-2.0-0.dll")]
 		static extern IntPtr g_malloc(UIntPtr size);
 
+		public static IntPtr Malloc (ulong size)
+		{
+			return g_malloc (new UIntPtr (size));
+		}
+
 		static bool check_sixtyfour () {
 			int szint = Marshal.SizeOf (typeof (int));
 			int szlong = Marshal.SizeOf (typeof (long));
